.. _release_notes:

Release Notes
*************

The following are release notes used on PyPI, Sourceforge and mailing lists for
Pootle releases.

.. toctree::
   :maxdepth: 1

   1.11.0 <1.11.0>
   1.11.0-rc1 <1.11.0-rc1>
   1.10.0 <1.10.0>
   1.9.0 <1.9.0>
   1.8.1 <1.8.1>
